# API Reference

::: thecodecrate_pipeline.processors
    options:
        show_if_no_docstring: true
        preload_modules:
            - "_api"
            - "thecodecrate_pipeline"
        members:
            - ChainedProcessor
            - InterruptibleProcessor
            - ChainedProcessorInterface
            - InterruptibleProcessorInterface
